==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/dav-KE.pl <==
{
  am_pm_abbreviated => [
    "Luma lwa K",
    "luma lwa p"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "dav-KE",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Jim",
    "Kaw",
    "Kad",
    "Kan",
    "Kas",
    "Ngu",
    "Jum"
  ],
  day_format_narrow => [
    "J",
    "K",
    "K",
    "K",
    "K",
    "N",
    "J"
  ],
  day_format_wide => [
    "Kuramuka jimweri",
    "Kuramuka kawi",
    "Kuramuka kadadu",
    "Kuramuka kana",
    "Kuramuka kasanu",
    "Kifula nguwo",
    "Ituku ja jumwa"
  ],
  day_stand_alone_abbreviated => [
    "Jim",
    "Kaw",
    "Kad",
    "Kan",
    "Kas",
    "Ngu",
    "Jum"
  ],
  day_stand_alone_narrow => [
    "J",
    "K",
    "K",
    "K",
    "K",
    "N",
    "J"
  ],
  day_stand_alone_wide => [
    "Kuramuka jimweri",
    "Kuramuka kawi",
    "Kuramuka kadadu",
    "Kuramuka kana",
    "Kuramuka kasanu",
    "Kifula nguwo",
    "Ituku ja jumwa"
  ],
  era_abbreviated => [
    "KK",
    "BK"
  ],
  era_narrow => [
    "KK",
    "BK"
  ],
  era_wide => [
    "Kabla ya Kristo",
    "Baada ya Kristo"
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Taita",
  month_format_abbreviated => [
    "Imb",
    "Kaw",
    "Kad",
    "Kan",
    "Kas",
    "Kar",
    "Mfu",
    "Wun",
    "Ike",
    "Iku",
    "Imw",
    "Iwi"
  ],
  month_format_narrow => [
    "I",
    "K",
    "K",
    "K",
    "K",
    "K",
    "M",
    "W",
    "I",
    "I",
    "I",
    "I"
  ],
  month_format_wide => [
    "Mori ghwa imbiri",
    "Mori ghwa kawi",
    "Mori ghwa kadadu",
    "Mori ghwa kana",
    "Mori ghwa kasanu",
    "Mori ghwa karandadu",
    "Mori ghwa mfungade",
    "Mori ghwa wunyanya",
    "Mori ghwa ikenda",
    "Mori ghwa ikumi",
    "Mori ghwa ikumi na imweri",
    "Mori ghwa ikumi na iwi"
  ],
  month_stand_alone_abbreviated => [
    "Imb",
    "Kaw",
    "Kad",
    "Kan",
    "Kas",
    "Kar",
    "Mfu",
    "Wun",
    "Ike",
    "Iku",
    "Imw",
    "Iwi"
  ],
  month_stand_alone_narrow => [
    "I",
    "K",
    "K",
    "K",
    "K",
    "K",
    "M",
    "W",
    "I",
    "I",
    "I",
    "I"
  ],
  month_stand_alone_wide => [
    "Mori ghwa imbiri",
    "Mori ghwa kawi",
    "Mori ghwa kadadu",
    "Mori ghwa kana",
    "Mori ghwa kasanu",
    "Mori ghwa karandadu",
    "Mori ghwa mfungade",
    "Mori ghwa wunyanya",
    "Mori ghwa ikenda",
    "Mori ghwa ikumi",
    "Mori ghwa ikumi na imweri",
    "Mori ghwa ikumi na iwi"
  ],
  name => "Taita Kenya",
  native_language => "Kitaita",
  native_name => "Kitaita Kenya",
  native_script => undef,
  native_territory => "Kenya",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "Kimu cha imbiri",
    "Kimu cha kawi",
    "Kimu cha kadadu",
    "Kimu cha kana"
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "Kimu cha imbiri",
    "Kimu cha kawi",
    "Kimu cha kadadu",
    "Kimu cha kana"
  ],
  script => undef,
  territory => "Kenya",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.17.tar.gz: DateTime-Locale-1.17/share/dav-KE.pl <==
{
  am_pm_abbreviated => [
    "Luma lwa K",
    "luma lwa p",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "dav-KE",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Jim",
    "Kaw",
    "Kad",
    "Kan",
    "Kas",
    "Ngu",
    "Jum",
  ],
  day_format_narrow => [
    "J",
    "K",
    "K",
    "K",
    "K",
    "N",
    "J",
  ],
  day_format_wide => [
    "Kuramuka jimweri",
    "Kuramuka kawi",
    "Kuramuka kadadu",
    "Kuramuka kana",
    "Kuramuka kasanu",
    "Kifula nguwo",
    "Ituku ja jumwa",
  ],
  day_stand_alone_abbreviated => [
    "Jim",
    "Kaw",
    "Kad",
    "Kan",
    "Kas",
    "Ngu",
    "Jum",
  ],
  day_stand_alone_narrow => [
    "J",
    "K",
    "K",
    "K",
    "K",
    "N",
    "J",
  ],
  day_stand_alone_wide => [
    "Kuramuka jimweri",
    "Kuramuka kawi",
    "Kuramuka kadadu",
    "Kuramuka kana",
    "Kuramuka kasanu",
    "Kifula nguwo",
    "Ituku ja jumwa",
  ],
  era_abbreviated => [
    "KK",
    "BK",
  ],
  era_narrow => [
    "KK",
    "BK",
  ],
  era_wide => [
    "Kabla ya Kristo",
    "Baada ya Kristo",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Taita",
  month_format_abbreviated => [
    "Imb",
    "Kaw",
    "Kad",
    "Kan",
    "Kas",
    "Kar",
    "Mfu",
    "Wun",
    "Ike",
    "Iku",
    "Imw",
    "Iwi",
  ],
  month_format_narrow => [
    "I",
    "K",
    "K",
    "K",
    "K",
    "K",
    "M",
    "W",
    "I",
    "I",
    "I",
    "I",
  ],
  month_format_wide => [
    "Mori ghwa imbiri",
    "Mori ghwa kawi",
    "Mori ghwa kadadu",
    "Mori ghwa kana",
    "Mori ghwa kasanu",
    "Mori ghwa karandadu",
    "Mori ghwa mfungade",
    "Mori ghwa wunyanya",
    "Mori ghwa ikenda",
    "Mori ghwa ikumi",
    "Mori ghwa ikumi na imweri",
    "Mori ghwa ikumi na iwi",
  ],
  month_stand_alone_abbreviated => [
    "Imb",
    "Kaw",
    "Kad",
    "Kan",
    "Kas",
    "Kar",
    "Mfu",
    "Wun",
    "Ike",
    "Iku",
    "Imw",
    "Iwi",
  ],
  month_stand_alone_narrow => [
    "I",
    "K",
    "K",
    "K",
    "K",
    "K",
    "M",
    "W",
    "I",
    "I",
    "I",
    "I",
  ],
  month_stand_alone_wide => [
    "Mori ghwa imbiri",
    "Mori ghwa kawi",
    "Mori ghwa kadadu",
    "Mori ghwa kana",
    "Mori ghwa kasanu",
    "Mori ghwa karandadu",
    "Mori ghwa mfungade",
    "Mori ghwa wunyanya",
    "Mori ghwa ikenda",
    "Mori ghwa ikumi",
    "Mori ghwa ikumi na imweri",
    "Mori ghwa ikumi na iwi",
  ],
  name => "Taita Kenya",
  native_language => "Kitaita",
  native_name => "Kitaita Kenya",
  native_script => undef,
  native_territory => "Kenya",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Kimu cha imbiri",
    "Kimu cha kawi",
    "Kimu cha kadadu",
    "Kimu cha kana",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Kimu cha imbiri",
    "Kimu cha kawi",
    "Kimu cha kadadu",
    "Kimu cha kana",
  ],
  script => undef,
  territory => "Kenya",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}
